@@ -7,13 +7,15 @@ from libqtile.config import Group
 class GroupName(Enum):
     """Enumerated group names"""
 
-    WEB = "web"
-    CHAT = "chat"
-    TERM = "term"
-    PERSONAL = "personal"
-    DEV = "dev"
-    TMP = "tmp"
-    CALL = "call"
+    WEB = "WEB"
+    CHAT = "CHAT"
+    TERM = "TERM"
+    DEV = "DEV"
+    NULL = "NULL"
+    TMP = "TMP"
+    CALL = "CALL"
+    SANDBOX1 = "SNDBX1"
+    SANDBOX2 = "SNDBX2"
 
 
 groups = [Group(f"{ix+1}: {group.value}") for ix, group in enumerate(list(GroupName))]
